#
# spec file for package insighttoolkit
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2016 Angelos Tzotsos <tzotsos@opensuse.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __builder ninja
%define tarname ITK
%define libname lib%{name}5_4-1

# Do not use system eigen on aarch64 until fixed upstream:
# https://github.com/InsightSoftwareConsortium/ITK/issues/2903
%ifarch aarch64
%bcond_with system_eigen
%else
%bcond_without system_eigen
%endif

# Python >= 3.8 is required
%if 0%{?suse_version} > 1650
%bcond_with python
%else
# Unreleased master branch of swig required <https://github.com/InsightSoftwareConsortium/ITK/issues/4746>
%bcond_with python
%endif

Name:           insighttoolkit
Version:        5.4.0
Release:        1.7
Summary:        Toolkit for scientific image processing, segmentation, and registration
License:        Apache-2.0
URL:            https://www.itk.org
Source0:        https://github.com/InsightSoftwareConsortium/ITK/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  CastXML-devel
BuildRequires:  bison
BuildRequires:  cmake
BuildRequires:  dcmtk-devel
BuildRequires:  fdupes
BuildRequires:  fftw3-threads-devel
BuildRequires:  gcc-c++
BuildRequires:  gdcm-devel
BuildRequires:  gtest
BuildRequires:  hdf5-devel
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  vtk-devel
BuildRequires:  vtk-qt
BuildRequires:  xz
BuildRequires:  cmake(double-conversion)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpcrecpp)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(zlib)
%if %{with python}
BuildRequires:  python3-devel >= 3.8
BuildRequires:  swig >= 4.3
%endif
%if %{with system_eigen}
BuildRequires:  pkgconfig(eigen3)
%endif

%description
The Insight Toolkit (ITK) is a toolkit for N-dimensional scientific
image processing, segmentation, and registration.

%package devel
Summary:        Development files for ITK
Requires:       %{libname} = %{version}-%{release}
Requires:       dcmtk-devel
Requires:       double-conversion-devel
Requires:       fftw3-threads-devel
Requires:       hdf5-devel
Requires:       vtk-devel
Requires:       pkgconfig(expat)
Requires:       pkgconfig(fftw3)
Requires:       pkgconfig(libjpeg)
Requires:       pkgconfig(libpcrecpp)
Requires:       pkgconfig(libpng)
Requires:       pkgconfig(libtiff-4)
Requires:       pkgconfig(libxml-2.0)
Requires:       pkgconfig(zlib)
Provides:       lib%{name}-devel

%description devel
The Insight Toolkit (ITK) is a toolkit for N-dimensional scientific
image processing, segmentation, and registration.

This package provides development files for the ITK library.

%package -n %{libname}
Summary:        Toolkit for scientific image processing, segmentation, and registration
Conflicts:      libinsighttoolkit5

%description -n %{libname}
The Insight Toolkit (ITK) is a toolkit for N-dimensional scientific
image processing, segmentation, and registration.

This package provides shared libraries for ITK.

%package -n python3-itk
Summary:        Python bindings for ITK
Requires:       python3-numpy

%description -n python3-itk
The Insight Toolkit (ITK) is a toolkit for N-dimensional scientific
image processing, segmentation, and registration.

This package provides the modules for ITK's python bindings.

%prep
%autosetup -p1 -n %{tarname}-%{version}

%build
# Tests disabled because no KWStyle pkg for openSUSE
%cmake \
  -DITK_INSTALL_LIBRARY_DIR:PATH=%{_lib}/ \
  -DITK_INSTALL_INCLUDE_DIR:PATH=include/%{name}/ \
  -DITK_INSTALL_PACKAGE_DIR:PATH=%{_lib}/cmake/%{name}/ \
  -DITK_INSTALL_RUNTIME_DIR:PATH=%{_bindir} \
  -DITK_INSTALL_DOC_DIR=share/doc/packages/%{name}/ \
  -DBUILD_EXAMPLES:BOOL=ON \
  -DBUILD_SHARED_LIBS:BOOL=ON \
  -DBUILD_TESTING:BOOL=OFF \
  -DCMAKE_EXPORT_COMPILE_COMMANDS:BOOL=ON \
  -DITK_USE_FFTWD:BOOL=ON \
  -DITK_USE_FFTWF:BOOL=ON \
  -DITK_USE_SYSTEM_LIBRARIES:BOOL=ON \
  -DITK_USE_SYSTEM_CASTXML:BOOL=ON \
  -DITK_USE_SYSTEM_GDCM:BOOL=ON \
%if %{without system_eigen}
  -DITK_USE_SYSTEM_EIGEN:BOOL=OFF \
%endif
  -DITK_USE_SYSTEM_SWIG:BOOL=ON \
  -DITK_USE_SYSTEM_VXL:BOOL=OFF \
  -DVXL_BUILD_CORE_NUMERICS:BOOL=OFF \
  -DITK_FORBID_DOWNLOADS=ON \
  -DITK_WRAP_PYTHON:BOOL=%{?with_python:ON}%{!?with_python:OFF}

%cmake_build

%install
%cmake_install

%fdupes %{buildroot}/%{_prefix}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license LICENSE NOTICE
%{_libdir}/*.so.1

%files devel
%license LICENSE NOTICE
%{_includedir}/%{name}/
%{_libdir}/lib*.so
%{_libdir}/cmake/
%{_bindir}/itkTestDriver
%doc %{_docdir}/%{name}/

%if %{with python}
%files -n python3-itk
%license LICENSE NOTICE
%{python3_sitearch}/*.py
%{python3_sitearch}/itk/
%endif

%changelog
* Mon Jul  8 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.4.0:
  * No release notes.
- Drop patches incorporated upstream:
  * insighttoolkit-swig4_1-compat.patch
  * add-missing-includes.patch
- Disable python bindings for openSUSE < 1650 as python >= 3.8 is
  required and also for openSUSE >= 1650 as an unreleased version
  of swig is required.
* Fri Jan 19 2024 Atri Bhattacharya <badshah400@gmail.com>
- Add insighttoolkit-swig4_1-compat.patch -- Add swig 4.1+
  compatibility by defining SWIGPY_SLICEOBJECT; patch picked from
  upstream commit [gh#InsightSoftwareConsortium/ITK#3782].
* Mon Nov  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Mon Apr 10 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add add-missing-includes.patch: Add missing #include <cstdint>.
  Now exposed by gcc 13.
* Wed Jan 25 2023 Thorsten Kukuk <kukuk@suse.com>
- Remove unused libnsl build requires
* Fri Dec  2 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.3.0:
  * No release notes.
- Drop insighttoolkit-fno-sized-deallocation.patch: incorporated
  upstream.
- Enable builds for 32 bit, gh#InsightSoftwareConsortium/ITK#2529
  resolved.
- At least swig 4.0 required.
* Mon Aug 29 2022 Atri Bhattacharya <badshah400@gmail.com>
- Disable python bindings for openSUSE >= 1550 until swig related
  issues are sorted [gh#InsightSoftwareConsortium/ITK#3452].
- Add insighttoolkit-fno-sized-deallocation.patch: Add
  - fno-sized-deallocation for GCC 12; patch taken from upstream
  commit.
* Wed Apr 27 2022 Jan Engelhardt <jengelh@inai.de>
- Resolve rpmlint report "libinsighttoolkit5.x86_64: E:
  shlib-policy-name-error SONAME: libitkvnl-5.2.so.1, expected
  package suffix: 5_2-1"
* Thu Feb  3 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Do not use system eigen on aarch64 until fixed upstream:
  https://github.com/InsightSoftwareConsortium/ITK/issues/2903
* Mon Aug 16 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.2.1:
  * Undocumented bug fixes (no release notes).
- Cleanup: Drop an unused macro from the spec file.
* Sat May 15 2021 Atri Bhattacharya <badshah400@gmail.com>
- Disable builds for i586 for now
  (gh#InsightSoftwareConsortium/ITK#2529).
* Wed May  5 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.2.0:
  * No release notes.
- Drop upstreamed patches:
  * reproducible.patch,
  * itklbfgs-linking.patch, and
  * nrrdio-linking.patch.
* Thu Dec 10 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.1.2:
  * Platform Fixes: Updatie ITKSimpleITKFilters remote module.
  * Bug Fixes
  - Address divide by zero error in SignedMaurerDistance.
  - Support MRC2014 mode 0 as signed 8-bit integer.
  - itkhdf5 installed paths were incorrect with recent hdf5
    versions.
  - MinPriorityQueueElementWrapper constructor needs default
    constructor.
  - Add TIFFImageIO support for unsigned int and int pixel
    types.
  - Fix MatrixOffsetTransformBase SetFixedParameters if too few
    params.
  * Style Changes: Improve function types used in
    SignedMaurerDistanceMap.
* Mon Dec  7 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update RAM requirements to avoid OOM seen with LTO
* Tue Oct  6 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Re-enable build for aarch64 since eigen has been fixed
* Thu Aug 20 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.1.1:
  * VtkGlue module-Provide support for VTK new cmake targets.
  * Add VXL support for GCC 9.
  * Use double-conversion's CMake targets.
  * Fix for non-system double-conversion build.
  * Patch missing const qualifier to GDCM dircos_comp comparison.
  * Back-port gh#InsightSoftwareConsortium/ITK#1165 to support
    Visual Studio 2019.
  * Address bug with small size in output of SliceImageFilter.
  * Update GDCM to latest on the release-2.8 branch.
  * Don't use InsertElement which modifies MTime.
  * Address buffer overflow with deprecated GDCM1 interface.
  * update download location for pre-built ICU for Visual Studio.
  * Duplicate ImageToImageFilter wrapping of ULL.
  * Double scaling introduced in refactoring.
  * Add missing const qualifier.
  * Add StatisticsImageFilter::SetNumberOfStreamDivisions Python.
  * Make column limit more stringent in the examples.
  * CUFFTW paths were not being set and unnecessary FFTW files
    used.
  * Disable dynamic threading in noise filter.
  * Added vcl compiler detection for GCC 10.x.
  * Specify itk package in SWIG Python modules.
  * Fix warning in PointSetToPointSetMetricv4
    (gh#InsightSoftwareConsortium/ITK#1820).
  * Fix segfault with empty CompositeTransforms.
  * Fix additional segmentation faults with empty Composite.
  * Address missing brace initializer warning.
  * Address memory leak in CastSpatialOpbjectTest.
  * Simplify itk.BlockMatchingImageFilter feature points PointSet
    mangling.
  * ITK_WRAP_PYTHON_PROCCESS to ITK_WRAP_PYTHON_PROCESS.
  * Accept TemplateTypeError with fallback_only.
  * Import C module from Python submodule.
  * Fix Segfault in Delaunay Filter.
  * ITKModuleExternal CMAKE_LIBRARY_OUTPUT_DIRECTORY when
    wrapping.
  * Avoid duplicate itk.PointSetD3 wrapping.
  * Wrap ExtractImageFilter for UL.
  * Use Numpy bridge with array of dimension 1.
  * Restore LICENSE accidentally overwritten by a merge commit.
  * Rename libPNG's license to match the original one.
  * Support casting unsigned long pixel types in Python.
  * Empty image support in image_from_xarray.
  * Remove netnlib triangle classes.
  * Remove License incompatible netlib files from vxl updates.
  * improve helpers of itk.Filters.
  * Do not reference FE_DIVBYZERO FE_INVALID with Emscripten.
  * Add missing enumerate with multi-ndarray-output itk filters.
  * Do not wrap unsigned char for connected component output.
  * Fix issue gh#InsightSoftwareConsortium/ITK#1950,
    ImageMaskSpatialObject access outside image buffer.
  * Register Dask serialization functions for NDArrayITKBase.
  * Add testing data content links for ITK 5.1.1.
- Drop insighttoolkit-drop-netlib-triangle-files.patch:
  incorporated upstream.
- Disable builds for aarch64: Known Eigen+CastXML issue
  [https://gitlab.com/libeigen/eigen/-/issues/1979].
* Thu Aug 20 2020 Martin Liška <mliska@suse.cz>
- Use memoryperjob constraint instead of %%limit_build macro.
* Thu Jul 30 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to make build results independent
  of build machine CPU (boo#1100677,
  gh#InsightSoftwareConsortium/ITK#1939).
* Tue Jul 14 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add insighttoolkit-drop-netlib-triangle-files.patch: Drop netlib
  triangle files and any linking to them due to licensing issues;
  patch from upstream [gh#InsightSoftwareConsortium/ITK#1913].
* Wed Jun  3 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.1.0: See
  https://blog.kitware.com/itk-5-1-0-available-for-download/.
- Drop dcmtk-cmake.patch: no longer needed when using system
  dcmtk.
- Update itklbfgs-linking.patch and nrrdio-linking.patch to
  upstream-blessed versions (minor changes only)
  [gh#InsightSoftwareConsortium/ITK#1867,
  gh#InsightSoftwareConsortium/ITK#1878].
- New BuildRequires: pkgconfig(libpcrecpp) and bison.
- Drop BuildRequires: tcpd-devel, no longer needed.
- Add necessary Requires: python3-numpy to python3-%%{name}
  package.
- Update Requires for devel package and convert existing Requires
  to pkgconfig equivalents where possible.
- Pass -DITK_USE_SYSTEM_SWIG:BOOL=ON to cmake, otherwise it
  defaults to OFF and tries to download swig.
- Drop -DITK_USE_STRICT_CONCEPT_CHECKING:BOOL=ON option passed to
  cmake: no longer used.
- Drop -DITK_WRAPPING option passed to cmake: obsoleted by
  - DITK_WRAP_PYTHON.
- No longer need to `export CXXFLAGS+=" -I%%{_includedir}/gdcm/"`
  [gh#InsightSoftwareConsortium/ITK#1768].
- Drop Group tags.
- Improve Summary and descriptions for packages.
* Mon May 18 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 5.0.1: See
  https://discourse.itk.org/t/itk-5-0-1-has-been-released/2094.
- Changes from version 5.0.0: See
  https://discourse.itk.org/t/itk-5-0-0-has-been-released/1931.
- Drop add_gcc9_support.patch: no longer required with upstream
  support for up to GCC 10 baked in.
- Pass options to %%cmake to set proper install paths when
  installing; prevents the need to manually move installed libs
  around. Drop sed BuildRequires that is no longer required as a
  consequence.
- Enable python3 wrapping (needed for tomviz, for instance); split
  out separate python3-itk package. Introduces BuildRequires:
  python3-devel.
- Add BuildRequires: memory-constraints and use %%limit_build
  to require at least 2 GiB memory per thread; OOM failures
  otherwise.
- Update _constraints file: at least 24 GB (!!!) disk space and 2
  GB memory now required.
- Use ninja for build (BuildRequires: ninja); compile using
  %%cmake_build instead of make directly.
- Additional system library dependencies: CastXML-devel, gtest,
  double-conversion, and gdcm-devel.
- Convert BuildRequires to pkgconfig() or cmake() based ones
  wherever possible.
- Update URL and Source URL in keeping with upstream's move to
  github.
- Drop conditionals for old openSUSE versions.
* Sat Jul  6 2019 Jan Engelhardt <jengelh@inai.de>
- Remove filler wording from description.
- Limit %%fdupes to /usr subvolume.
* Tue Jul  2 2019 Dirk Stoecker <opensuse@dstoecker.de>
- update to 4.13.2
- Replace add_gcc8_support.patch with add_gcc9_support.patch
- Update dcmtk-cmake.patch
* Thu May 16 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add missing libxml2-devel build dep (Fix Leap 15.1 and TW builds)
* Mon Jul  2 2018 guillaume.gardet@opensuse.org
- Add patch to add support to GCC8:
  * add_gcc8_support.patch
* Thu Nov 23 2017 bruno@ioda-net.ch
- Add _constaints file with minimal disk space of 6GB
  Fix build on powerpc
* Mon Nov 20 2017 guillaume@opensuse.org
- Change group from 'Development/Libraries' to 'Development/Libraries/C and C++'
* Mon Nov 20 2017 guillaume@opensuse.org
- Update to 4.12.2 (Fix Tumbleweed build)
- Remove doubleconv.patch
* Sun Oct  2 2016 tzotsos@opensuse.org
- Update to 4.10.0
- Ported doubleconv.patch to new version
- Added dcmtk-cmake.patch to revert recent git changes that work with latest dcmtk .cmake files
* Sat Oct  1 2016 tzotsos@opensuse.org
- python-vtk not needed and removed from spec file
* Fri Jan  1 2016 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Use cmake macros
- Use spdx license and install license file
- Use url for source
* Sat Dec 26 2015 Angelos Tzotsos <tzotsos@opensuse.org> - 4.8.2
- Update to 4.8.2
* Fri Aug 14 2015 Angelos Tzotsos <tzotsos@opensuse.org> - 4.7.2
- Update to 4.7.2
* Fri Feb 27 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- Renamed package to insighttoolkit
* Wed Jan 14 2015 Angelos Tzotsos <tzotsos@opensuse.org> - 4.6.0
- Update to 4.6.0
* Sat Mar  1 2014 Angelos Tzotsos <tzotsos@opensuse.org> - 4.5.1
- Initial build
